/*
    GNUbik -- A 3 dimensional magic cube game.
    Copyright (C) 2003  John Darrington

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3 of the License,  or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GLAREA_H
#define GLAREA_H

#include <gtk/gtk.h>


extern GLdouble fovy;
extern GLdouble cp_near,  cp_far;


void re_initialize_glarea (void);


void register_gl_callbacks (GtkWidget * glxarea);
GtkWidget * create_gl_area (GtkWidget * containerWidget,  GtkWidget * adjacentWidget);


void modelViewInit (void);

void postRedisplay (void);

void lighting_init (void);

void projection_init (int jitter);

#endif
